@@ -19,7 +19,7 @@ from docopt import docopt
 from . import __version__
 
 
-CMDS = ['cheat', 'clone', 'grade', 'push']
+CMDS = ['cheat', 'clone', 'grade', 'init', 'push']
 
 
 def main():
